.. Geolocate documentation master file, created by
   sphinx-quickstart on Sat Jul 11 01:31:21 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Geolocate's documentation!
=====================================

Packages:
---------
.. toctree::
   :maxdepth: 1

   geolocate.classes

Scripts:
--------

* **glocate.py**

.. automodule:: geolocate.glocate
    :members:
    :special-members: __init__
    :undoc-members:
    :show-inheritance:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

